@@ -11,7 +11,7 @@ from tqdm import tqdm
 import pandas as pd
 from src.models.utils import init_tokenizer, mask_tokens
 
-fileConfig('src/log_config.ini')
+fileConfig('src/resources/log_config.ini')
 logger = logging.getLogger(__name__)
 
 
