@@ -22,7 +22,7 @@ import wandb
 from src.data.camembert_mlm_dataset import CamemBERTMaskedLMDataset
 from src.models.utils import count_parameters, init_tokenizer
 
-fileConfig('src/log_config.ini')
+fileConfig('src/resources/log_config.ini')
 logger = logging.getLogger(__name__)
 
 
